@@ -2,7 +2,7 @@ package Test2::Harness::UI;
 use strict;
 use warnings;
 
-our $VERSION = '0.000101';
+our $VERSION = '0.000102';
 
 use Router::Simple;
 use Text::Xslate(qw/mark_raw/);
@@ -31,6 +31,8 @@ use Test2::Harness::UI::Controller::Durations;
 use Test2::Harness::UI::Controller::Coverage;
 use Test2::Harness::UI::Controller::Failed;
 
+use Test2::Harness::UI::Controller::Interactions;
+
 use Test2::Harness::UI::Util qw/share_dir/;
 use Test2::Harness::UI::Response qw/resp error/;
 
@@ -52,6 +54,11 @@ sub init {
     $router->connect('/user' => {controller => 'Test2::Harness::UI::Controller::User'})
         unless $config->single_user;
 
+    $router->connect('/interactions/:id'               => {controller => 'Test2::Harness::UI::Controller::Interactions'});
+    $router->connect('/interactions/:id/:context'      => {controller => 'Test2::Harness::UI::Controller::Interactions'});
+    $router->connect('/interactions/data/:id'          => {controller => 'Test2::Harness::UI::Controller::Interactions', data => 1});
+    $router->connect('/interactions/data/:id/:context' => {controller => 'Test2::Harness::UI::Controller::Interactions', data => 1});
+
     $router->connect('/project/:id'           => {controller => 'Test2::Harness::UI::Controller::Project'});
     $router->connect('/project/:id/stats'     => {controller => 'Test2::Harness::UI::Controller::Project', stats => 1});
     $router->connect('/project/:id/:n'        => {controller => 'Test2::Harness::UI::Controller::Project'});
